@@ -19,6 +19,7 @@ describe 'heat' do
       :flavor                => 'keystone',
       :keystone_password     => 'secretpassword',
       :heat_clients_url      => '<SERVICE DEFAULT>',
+      :purge_config          => false,
     }
   end
 
@@ -79,6 +80,12 @@ describe 'heat' do
       )
     end
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('heat_config').with({
+        :purge => false
+      })
+    end
+
     it 'has db_sync enabled' do
       is_expected.to contain_class('heat::db::sync')
     end
@@ -91,12 +98,14 @@ describe 'heat' do
       is_expected.to contain_heat_config('DEFAULT/max_json_body_size').with_value('<SERVICE DEFAULT>')
     end
 
-    it 'configures project_domain_id' do
-      is_expected.to contain_heat_config('trustee/project_domain_id').with_value( 'Default' )
+    it 'configures project_domain_*' do
+      is_expected.to contain_heat_config('trustee/project_domain_id').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('trustee/project_domain_name').with_value( 'Default' )
     end
 
-    it 'configures user_domain_id' do
-      is_expected.to contain_heat_config('trustee/user_domain_id').with_value( 'Default' )
+    it 'configures user_domain_*' do
+      is_expected.to contain_heat_config('trustee/user_domain_id').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('trustee/user_domain_name').with_value( 'Default' )
     end
 
     it 'configures auth_plugin' do
@@ -138,6 +147,10 @@ describe 'heat' do
       is_expected.to contain_heat_config('clients_heat/url').with_value('<SERVICE DEFAULT>')
     end
 
+    it 'configures keystone_authtoken memcached' do
+      is_expected.to contain_heat_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
+    end
+
     it_configures "with default auth method"
   end
 
@@ -374,19 +387,25 @@ describe 'heat' do
       is_expected.to contain_heat_config('keystone_authtoken/username').with_value("heat")
       is_expected.to contain_heat_config('keystone_authtoken/password').with_secret( true )
       is_expected.to contain_heat_config('keystone_authtoken/project_name').with_value("services")
-      is_expected.to contain_heat_config('keystone_authtoken/user_domain_id').with_value('Default')
-      is_expected.to contain_heat_config('keystone_authtoken/project_domain_id').with_value('Default')
+      is_expected.to contain_heat_config('keystone_authtoken/user_domain_name').with_value('Default')
+      is_expected.to contain_heat_config('keystone_authtoken/project_domain_name').with_value('Default')
+      is_expected.to contain_heat_config('keystone_authtoken/user_domain_id').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('keystone_authtoken/project_domain_id').with_value('<SERVICE DEFAULT>')
     end
   end
 
-  shared_examples_for "with custom keystone project_domain_id and user_domain_id" do
+  shared_examples_for "with custom keystone project_domain_* and user_domain_*" do
     before do
       params.merge!({
-        :keystone_project_domain_id => 'domain1',
-        :keystone_user_domain_id => 'domain1',
+        :keystone_project_domain_id   => 'domain1',
+        :keystone_user_domain_id      => 'domain1',
+        :keystone_project_domain_name => 'domain1',
+        :keystone_user_domain_name    => 'domain1',
       })
     end
-    it 'configures project_domain_id and user_domain_id' do
+    it 'configures project_domain_* and user_domain_*' do
+      is_expected.to contain_heat_config('trustee/project_domain_name').with_value("domain1");
+      is_expected.to contain_heat_config('trustee/user_domain_name').with_value("domain1");
       is_expected.to contain_heat_config('trustee/project_domain_id').with_value("domain1");
       is_expected.to contain_heat_config('trustee/user_domain_id').with_value("domain1");
     end
